@@ -1,21 +1,8 @@
-/******************************************************************************
- *   Copyright (C) 2010 by Sebastian Doerner <sebastian@sebastian-doerner.de> *
- *                                                                            *
- *   This program is free software; you can redistribute it and/or modify     *
- *   it under the terms of the GNU General Public License as published by     *
- *   the Free Software Foundation; either version 2 of the License, or        *
- *   (at your option) any later version.                                      *
- *                                                                            *
- *   This program is distributed in the hope that it will be useful,          *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of           *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
- *   GNU General Public License for more details.                             *
- *                                                                            *
- *   You should have received a copy of the GNU General Public License        *
- *   along with this program; if not, write to the                            *
- *   Free Software Foundation, Inc.,                                          *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA               *
- ******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Sebastian Doerner <sebastian@sebastian-doerner.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef CHECKOUTDIALOG_H
 #define CHECKOUTDIALOG_H
@@ -39,7 +26,7 @@ class CheckoutDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit CheckoutDialog(QWidget* parent = 0);
+    explicit CheckoutDialog(QWidget* parent = nullptr);
     /**
      * Returns the name of the selected tag or branch to be checkout out
      * @returns The name of the selected tag or branch
