@@ -1,22 +1,9 @@
-/***************************************************************************
- *   Copyright (C) 2011 by Vishesh Yadav <vishesh3y@gmail.com>             *
- *   Copyright (C) 2015 by Tomasz Bojczuk <seelook@gmail.com>              *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Vishesh Yadav <vishesh3y@gmail.com>
+    SPDX-FileCopyrightText: 2015 Tomasz Bojczuk <seelook@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "commitdialog.h"
 #include "hgwrapper.h"
@@ -55,7 +42,7 @@ HgCommitDialog::HgCommitDialog(QWidget *parent):
                      "\nplease check your KDE Frameworks installation."));
         return;
     }
-    m_fileDiffDoc = editor->createDocument(0);
+    m_fileDiffDoc = editor->createDocument(nullptr);
     m_fileDiffView = qobject_cast<KTextEditor::View*>(m_fileDiffDoc->createView(this));
     m_fileDiffView->setStatusBarEnabled(false);
     m_fileDiffDoc->setReadWrite(false);
@@ -112,7 +99,7 @@ HgCommitDialog::HgCommitDialog(QWidget *parent):
     // the commit box itself
     QGroupBox *messageGroupBox = new QGroupBox;
     QVBoxLayout *commitLayout = new QVBoxLayout;
-    m_commitMessage = editor->createDocument(0);
+    m_commitMessage = editor->createDocument(nullptr);
     KTextEditor::View *messageView =
               qobject_cast<KTextEditor::View*>(m_commitMessage->createView(this));
     messageView->setStatusBarEnabled(false);
@@ -366,7 +353,7 @@ void HgCommitDialog::createCopyMessageMenu()
     QString output;
     hgw->executeCommand(QLatin1String("log"), args, output);
 
-    const QStringList messages = output.split('\n', QString::SkipEmptyParts);
+    const QStringList messages = output.split('\n', Qt::SkipEmptyParts);
     for (const QString &msg : messages) {
         QAction *action = m_copyMessageMenu->addAction(msg.left(40)); // max 40 characters
         action->setData(msg); // entire description into action data
