@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2011 by Vishesh Yadav <vishesh3y@gmail.com>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Vishesh Yadav <vishesh3y@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "pulldialog.h"
 #include "hgwrapper.h"
@@ -23,7 +10,6 @@
 #include "pathselector.h"
 #include "fileviewhgpluginsettings.h"
 
-
 #include <QStringList>
 #include <QTextCodec>
 #include <QHeaderView>
@@ -98,7 +84,7 @@ void HgPullDialog::getHgChangesArguments(QStringList &args)
 
 void HgPullDialog::parseUpdateChanges(const QString &input)
 {
-    QStringList list = input.split("  ", QString::SkipEmptyParts);
+    QStringList list = input.split("  ", Qt::SkipEmptyParts);
     QTableWidgetItem *author = new QTableWidgetItem;
     QTableWidgetItem *changeset = new QTableWidgetItem;
     QTableWidgetItem *date = new QTableWidgetItem;
